@@ -81,7 +81,11 @@ def getImage(img):
 def send_v2(chat, result, rotate=0, send_all=False, no_cut=False, size_factor = None):
 	# todo: cached_url may want to make sure the video fn ends with mp4...	
 	if result.video:
-		return sendVideo(chat, result)
+		try:
+			return sendVideo(chat, result)
+		except Exception as e:
+			if not result.imgs:
+				raise e
 
 	img_limit = 100 if send_all else 10
 	if no_cut:
